@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-__version__ = '1.2.4'
+__version__ = '1.2.10'
 
 from    pathlib                 import Path
 
@@ -14,7 +14,7 @@ from    threading               import current_thread
 from    datetime                import datetime, timezone
 from    argparse                import Namespace
 
-from    typing                  import Any
+from    typing                  import Any, Callable
 
 from    pftel_client            import Client
 from    pftel_client.models     import log_structured, log_response
@@ -26,6 +26,8 @@ from    argparse                import  RawTextHelpFormatter
 from    pftag                   import  pftag
 from    .                       import  data
 
+import  functools
+
 def parser_setup(str_desc) -> ArgumentParser:
     parser:ArgumentParser = ArgumentParser(
                 description         = str_desc,
@@ -329,6 +331,76 @@ class Pflog:
         self.options.log = message
         return self.run()
 
+def tel_logTime(_func:Callable  = None, *,
+                pftelDB:str     = '',
+                event:str       = '',
+                log:str         = ''):
+    """A decorator that times (and logs) a method.
+
+    If called without any arguments, this decorator simply prints the time
+    (seconds) that a method took to execute. If called with named args, will
+    transmit the time (and optional log message) as an event to a pftelDB
+    server.
+
+    Sometimes the pftelDB address is within the set of arguments passed to the
+    wrapped function. This decorator attempts to examine the wrapped function args
+    in an attempt to find/extract a namespace that contains an attribute called
+    'pftelDB' unless pftelDB is explicitly passed as a named argument.
+
+    Args:
+        _func (Callable, optional): the function to wrap. Defaults to None.
+        pftelDB (str, optional): telemetry server address. Defaults to ''.
+        event (str, optional): the name of this event. Defaults to ''.
+        log (str, optional): optional log message. Defaults to ''.
+    """
+    def decorator_time(func: Callable) -> Callable:
+
+        def pftelDB_determine(*args):
+            """Examine the *args for a namespace that contains an attribute
+            'pftelDB'. If found, return that attribute value, else return
+            an empty string.
+
+            Returns:
+                _type_: _description_
+            """
+            pftelDB:str     = ''
+            for arg in args:
+                if type(arg) == Namespace:
+                    if hasattr(arg, 'pftelDB'):
+                        pftelDB = arg.pftelDB
+            return pftelDB
+
+        @functools.wraps(func)
+        def wrapped(*args, **kwargs) -> Any:
+            pftelDBcopy:str     = ''
+            d_log:dict          = {}
+            tagger:pftag.Pftag  = pftag.Pftag({})
+            str_event:str       = 'analysisEvent'
+            dt_start:datetime   = pftag.timestamp_dt(tagger(r'%timestamp')['result'])
+            f_ret:Any           = func(*args, **kwargs)
+            dt_end:datetime     = pftag.timestamp_dt(tagger(r'%timestamp')['result'])
+            ft:float            = (dt_end - dt_start).total_seconds()
+            print(f"{func} executed in {ft} second(s).")
+            pftelDBcopy         = pftelDB
+            if not pftelDBcopy:
+                pftelDBcopy     = pftelDB_determine(*args)
+            if pftelDBcopy:
+                if event:
+                    str_event   = event
+                pftelDBcopy     = '/'.join(pftelDBcopy.split('/')[:-1] + [str_event])
+                d_log:dict      = pfprint(
+                                    pftelDBcopy,
+                                    log,
+                                    appName     = str_event,
+                                    execTime    = ft
+                                )
+            return f_ret, d_log
+        return wrapped
+    if _func is None:
+        return decorator_time
+    else:
+        return decorator_time(_func)
+
 def pfprint(pftelspec:str, message:str, **kwargs) -> str:
     """
     A simple "standalone" function for "printing" to
@@ -340,7 +412,7 @@ def pfprint(pftelspec:str, message:str, **kwargs) -> str:
     elements.
 
     Args:
-        pftelspec (str): A pftelFQS string denoting
+        pftelspec (str): A pftelDB string denoting the pftel URL
         message (str): a message to POST
 
     kwargs:
@@ -361,6 +433,7 @@ def pfprint(pftelspec:str, message:str, **kwargs) -> str:
     logObject:str       = ""
     logCollection:str   = ""
     logEvent:str        = ""
+    pftelspec           = pftelspec.strip()
     d_log               = {
         "status":       False,
         "reply":        None,
